@@ -98,6 +98,60 @@ xfce_gdk_screen_get_active (gint *monitor_return)
 }
 
 
+/**
+ * xfce_gdk_screen_get_geometry:
+ *
+ * Returns the width and height of the default #GdkScreen.
+ * This is a replacement for gdk_screen_width/gdk_screen_height.
+ *
+ * Return value: (transfer full): a newly created #GdkRectangle
+ * containing the width and height of the screen.
+ *
+ * Since: 4.14
+ **/
+GdkRectangle *
+xfce_gdk_screen_get_geometry (void)
+{
+  GdkRectangle *geometry;
+
+#if GTK_CHECK_VERSION (3, 22, 0)
+  gint x, y, w, h;
+  int num_monitors;
+  GdkDisplay *display;
+  GdkRectangle rect;
+  GdkMonitor *monitor;
+
+  geometry = g_new0 (GdkRectangle, 1);
+
+  display = gdk_display_get_default ();
+  num_monitors = gdk_display_get_n_monitors (display);
+
+  x = y = G_MAXINT;
+  w = h = G_MININT;
+
+  for (int i = 0; i < num_monitors; i++)
+    {
+      monitor = gdk_display_get_monitor (display, i);
+      gdk_monitor_get_geometry (monitor, &rect);
+
+      x = MIN (x, rect.x);
+      y = MIN (y, rect.y);
+      w = MAX (w, rect.x + rect.width);
+      h = MAX (h, rect.y + rect.height);
+    }
+
+  geometry->width = w - x;
+  geometry->height = h - y;
+#else
+  geometry = g_new0 (GdkRectangle, 1);
+
+  geometry->width = gdk_screen_width ();
+  geometry->height = gdk_screen_height ();
+#endif
+
+  return geometry;
+}
+
 
 #define __XFCE_GDK_EXTENSIONS_C__
 #include <libxfce4ui/libxfce4ui-aliasdef.c>
