@@ -31,6 +31,10 @@
 #include <config.h>
 #endif
 
+#ifdef HAVE_STRING_H
+#include <string.h>
+#endif
+
 #include <gtk/gtk.h>
 #include <pango/pango.h>
 
@@ -72,7 +76,7 @@ xfce_gtk_button_new_mixed (const gchar *stock_id,
     {
       button = gtk_button_new_with_mnemonic (label);
 
-      if (stock_id != NULL)
+      if (stock_id != NULL && strlen(stock_id) > 0)
         {
           /* create image widget */
 #if !GTK_CHECK_VERSION (3, 10, 0)
