@@ -1,20 +1,21 @@
 /*
- *  Copyright (c) 2009 Brian Tarricone <brian@terricone.org>
- *  Copyright (C) 1999 Olivier Fourdan (fourdan@xfce.org)
+ * Copyright (c) 2009 Brian Tarricone <brian@terricone.org>
+ * Copyright (C) 1999 Olivier Fourdan <fourdan@xfce.org>
  *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
- *  License as published by the Free Software Foundation; either
- *  version 2.1 of the License, or (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
  *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
- *  License along with this library; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301 USA
  */
 
 #ifndef __XFCE_SM_CLIENT_H__
@@ -33,6 +34,26 @@
 #define XFCE_IS_SM_CLIENT_CLASS(klass)  (G_TYPE_CHECK_CLASS_TYPE((klass), XFCE_TYPE_SM_CLIENT))
 #define XFCE_SM_CLIENT_GET_CLASS(obj)   (G_TYPE_INSTANCE_GET_CLASS((obj), XFCE_TYPE_SM_CLIENT, XfceSMClientClass))
 
+/**
+ * XFCE_SM_CLIENT_ERROR:
+ *
+ * Error domain for XfceSmCLient. Errors in this domain will be from the #XfceSmCLientErrorEnum enumeration.
+ * See #GError for more information on error domains.
+ **/
+#define XFCE_SM_CLIENT_ERROR xfce_sm_client_error_quark()
+
+/**
+ * XfceSmCLientErrorEnum:
+ * @XFCE_SM_CLIENT_ERROR_FAILED: Failed to connect to the session manager.
+ * @XFCE_SM_CLIENT_ERROR_INVALID_CLIENT: Session does not have a valid client id.
+ *
+ * Error codes returned by XfceSmCLient functions.
+ **/
+typedef enum {
+  XFCE_SM_CLIENT_ERROR_FAILED,
+  XFCE_SM_CLIENT_ERROR_INVALID_CLIENT
+} XfceSmCLientErrorEnum;
+
 G_BEGIN_DECLS
 
 typedef enum
@@ -63,6 +84,8 @@ typedef struct _XfceSMClient  XfceSMClient;
 
 GType xfce_sm_client_get_type(void) G_GNUC_CONST;
 
+GQuark xfce_sm_client_error_quark (void);
+
 GOptionGroup *xfce_sm_client_get_option_group(gint argc,
                                               gchar **argv);
 
@@ -93,9 +116,9 @@ gboolean xfce_sm_client_is_resumed(XfceSMClient *sm_client);
 void xfce_sm_client_set_desktop_file(XfceSMClient *sm_client,
                                      const gchar *desktop_file);
 
-G_CONST_RETURN gchar *xfce_sm_client_get_client_id(XfceSMClient *sm_client);
+const gchar *xfce_sm_client_get_client_id(XfceSMClient *sm_client);
 
-G_CONST_RETURN gchar *xfce_sm_client_get_state_file(XfceSMClient *sm_client);
+const gchar *xfce_sm_client_get_state_file(XfceSMClient *sm_client);
 
 void xfce_sm_client_set_restart_style(XfceSMClient *sm_client,
                                       XfceSMClientRestartStyle restart_style);
@@ -107,11 +130,11 @@ guint8 xfce_sm_client_get_priority(XfceSMClient *sm_client);
 
 void xfce_sm_client_set_current_directory(XfceSMClient *sm_client,
                                           const gchar *current_directory);
-G_CONST_RETURN gchar *xfce_sm_client_get_current_directory(XfceSMClient *sm_client);
+const gchar *xfce_sm_client_get_current_directory(XfceSMClient *sm_client);
 
 void xfce_sm_client_set_restart_command(XfceSMClient *sm_client,
                                         gchar **restart_command);
-G_CONST_RETURN gchar * G_CONST_RETURN *
+const gchar * const *
 xfce_sm_client_get_restart_command(XfceSMClient *sm_client);
 
 G_END_DECLS
